pub struct AcceptPut {
pub media_ranges: Vec<Mime>,
}Expand description
Accept-Put header is defined in solid-protocol
7.1.1 The syntax for Accept-Put, using the ABNF syntax defined in Section 1.2 of RFC7231, is:
Accept-Put = "Accept-Put" ":" # media-range
The Accept-Put header specifies a comma-separated list of media ranges (with optional parameters) as defined by RFC7231, Section 5.3.2. The Accept-Put header, in effect, uses the same syntax as the HTTP Accept header minus the optional accept-params BNF production, since the latter does not apply to Accept-Put.Fields
media_ranges: Vec<Mime>List of media ranges in accept-put header.